# flake8: noqa

# This file is autogenerated by /metadata-ingestion/scripts/avro_codegen.py
# Do not modify manually!

# fmt: off
from .....schema_classes import DataHubIngestionSourceConfigClass
from .....schema_classes import DataHubIngestionSourceInfoClass
from .....schema_classes import DataHubIngestionSourceScheduleClass


DataHubIngestionSourceConfig = DataHubIngestionSourceConfigClass
DataHubIngestionSourceInfo = DataHubIngestionSourceInfoClass
DataHubIngestionSourceSchedule = DataHubIngestionSourceScheduleClass

# fmt: on
